@@ -22,7 +22,7 @@
  * @author blueyed: Daniel HAHLER
  * @author fplanque: Francois PLANQUE
  *
- * @version $Id: _blog_main.inc.php,v 1.93.2.1 2008/02/11 23:51:58 fplanque Exp $
+ * @version $Id: _blog_main.inc.php,v 1.93.2.6 2009/03/23 12:26:09 tblue246 Exp $
  */
 
 if( !defined('EVO_CONFIG_LOADED') ) die( 'Please, do not access this page directly.' );
@@ -120,8 +120,9 @@ if( $resolve_extra_path )
 		$Debuglog->add( 'Extra path info found! path_string=' . $path_string , 'params' );
 		//echo "path=[$path_string]<br />";
 
-		// Replace encoded ; with regular ; (used for tags)
-		$path_string = str_replace( '%3b', ';', $path_string );
+		// Replace encoded ; and : with regular ; and : (used for tags)
+		$path_string = str_replace( array( '%3b', '%3B', '%3a', '%3A' ),
+									array( ';', ';', ':', ':' ), $path_string );
 
 		// Slice the path:
 		$path_split = explode( '/', $path_string, 20 );
@@ -159,8 +160,8 @@ if( $resolve_extra_path )
 		{
 			// Does the pathinfo end with a / or a ; ?
 			$last_char = substr( $path_string, -1 );
-			if( $last_char == ';' )
-			{	// ENDING SEMI COLUMN -> We'll consider this to be a tag page
+			if( $last_char == '-' || $last_char == ':'|| $last_char == ';' )
+			{	// - : or ; -> We'll consider this to be a tag page
 				$last_part = $path_elements[count($path_elements)-1];
 				$tag = substr( $last_part, 0, strlen($last_part)-1 );
 				$tag = urldecode($tag);
@@ -183,7 +184,7 @@ if( $resolve_extra_path )
 				$pb = 1;   // Display pingbacks
 
 				$path_element = $path_elements[count($path_elements)-1];
-				if( preg_match( "#^p([0-9]+)$#", $path_element, $req_post ) )
+				if( preg_match( '#^p([0-9]+)$#', $path_element, $req_post ) )
 				{ // The last param is of the form p000
 					// echo 'post number';
 					$p = $req_post[1];		// Post to display
@@ -238,7 +239,7 @@ if( $resolve_extra_path )
 						}
 					}
 				}
-				elseif( preg_match( '|^[A-Za-z0-9\-]+$|', $last_part ) )
+				elseif( preg_match( '|^[A-Za-z0-9\-_]+$|', $last_part ) )	// UNDERSCORES for catching OLD URLS!!!
 				{	// We are pointing to a chapter/category:
 					$ChapterCache = & get_Cache( 'ChapterCache' );
 					/**
@@ -250,6 +251,7 @@ if( $resolve_extra_path )
 						// We are going to consider this to be a post title with a misplaced trailing slash.
 						// That happens when upgrading from WP for example.
 						$title = $last_part; // Will be sought later
+						$already_looked_into_chapters = true;
 					}
 					else
 					{	// We could match a chapter from the extra path:
@@ -308,18 +310,55 @@ if( !empty($p) || !empty($title) )
 	// Make sure the single post we're requesting (still) exists:
 	$ItemCache = & get_Cache( 'ItemCache' );
 	if( !empty($p) )
-	{
+	{	// Get from post ID:
 		$Item = & $ItemCache->get_by_ID( $p, false );
 	}
 	else
-	{
+	{	// Get from post title:
 		$title = preg_replace( '/[^A-Za-z0-9_]/', '-', $title );
 		$Item = & $ItemCache->get_by_urltitle( $title, false );
 	}
 	if( empty( $Item ) )
-	{	// Post doesn't exist! Let's go 404!
+	{	// Post doesn't exist!
+
 		// fp> TODO: ->viewing_allowed() for draft, private, protected and deprecated...
-		require $skins_path.'_404_not_found.main.php'; // error & exit
+
+		$title_fallback = false;
+
+		if( !empty($title) && empty($already_looked_into_chapters) )
+		{	// Let's try to fall back to a category/chapter...
+			$ChapterCache = & get_Cache( 'ChapterCache' );
+			/**
+			 * @var Chapter
+			 */
+			$Chapter = & $ChapterCache->get_by_urlname( $title, false );
+			if( !empty( $Chapter ) )
+			{	// We could match a chapter from the extra path:
+				$cat = $Chapter->ID;
+				$title_fallback = true;
+				$title = NULL;
+				// Also use the prefered posts per page for a cat
+				if( ! $posts = $Blog->get_setting( 'chapter_posts_per_page' ) )
+				{ // use blog default
+					$posts = $Blog->get_setting( 'posts_per_page' );
+				}
+			}
+		}
+
+		if( !empty($title) )
+		{	// Let's try to fall back to a tag...
+			if( $Blog->get_tag_post_count( $title ) )
+			{ // We could match a tag from the extra path:
+				$tag = $title;
+				$title_fallback = true;
+				$title = NULL;
+			}
+		}
+
+		if( ! $title_fallback )
+		{	// We were not able to fallback to anythign meaningful:
+			require $skins_path.'_404_not_found.main.php'; // error & exit
+		}
 	}
 }
 
@@ -406,18 +445,21 @@ if( isset( $skin ) )
 	{
 		debug_die( 'The requested skin name is invalid.' );
 	}
+	else if ( substr( $skin, 0, 1 ) != '_' /* not a feed skin */ && skin_exists( $skin )
+			  && ! skin_installed( $skin ) )
+	{	// The requested skin is not a feed skin and exists in the file system, but isn't installed:
+		debug_die( sprintf( T_( 'The skin [%s] is not installed on this system.' ),
+								htmlspecialchars( $skin ) ) );
+	}
 
 	// EXPERIMENTAL:
 	load_class( 'skins/model/_skin.class.php' );
 	$Skin = & new Skin();
-
 }
 else
 { // Use default skin from the database
 	$SkinCache = & get_cache( 'SkinCache' );
-
 	$Skin = & $SkinCache->get_by_ID( $Blog->skin_ID );
-
 	$skin = $Skin->folder;
 }
 
