@@ -29,7 +29,7 @@
  * @author blueyed: Daniel HAHLER.
  * @author fplanque: Francois PLANQUE.
  *
- * @version $Id: _template.funcs.php,v 1.14.2.2 2008/04/26 22:28:52 fplanque Exp $
+ * @version $Id: _template.funcs.php,v 1.14.2.3 2008/05/11 01:13:34 fplanque Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -315,7 +315,7 @@ function base_tag( $url, $target = NULL )
 	{
 		echo ' target="'.$target.'"';
 	}
-	echo ' />';
+	echo " />\n";
 }
 
 
