@@ -37,7 +37,7 @@
  * @author jeffbearer: Jeff BEARER
  * @author edgester: Jason EDGECOMBE
  *
- * @version $Id: _blog.class.php,v 1.31.2.1 2008/04/26 22:28:52 fplanque Exp $
+ * @version $Id: _blog.class.php,v 1.31.2.5 2008/12/29 14:03:59 waltercruz Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -73,6 +73,9 @@ class Blog extends DataObject
 	var $shortdesc; // description
 	var $longdesc;
 
+	/**
+	 * @var integer
+	 */
 	var $owner_user_ID;
 
 	/**
@@ -195,30 +198,30 @@ class Blog extends DataObject
 	/**
 	 * @param string
 	 */
-	function init_by_kind( $kind )
+	function init_by_kind( $kind, $name = NULL, $shortname = NULL, $urlname = NULL )
 	{
 		switch( $kind )
 		{
 			case 'photo':
-				$this->set( 'name', T_('My photoblog') );
-				$this->set( 'shortname', T_('Photoblog') );
-				$this->set( 'urlname', 'photo' );
+				$this->set( 'name', empty($name) ? T_('My photoblog') : $name );
+				$this->set( 'shortname', empty($shortname) ? T_('Photoblog') : $shortname );
+				$this->set( 'urlname', empty($urlname) ? 'photo' : $urlname );
 				$this->set_setting( 'posts_per_page', 1 );
 				$this->set_setting( 'archive_mode', 'postbypost' );
 				break;
 
 			case 'group':
-				$this->set( 'name', T_('Our blog') );
-				$this->set( 'shortname', T_('Group') );
-				$this->set( 'urlname', 'group' );
+				$this->set( 'name', empty($name) ? T_('Our blog') : $name );
+				$this->set( 'shortname', empty($shortname) ? T_('Group') : $shortname );
+				$this->set( 'urlname', empty($urlname) ? 'group' : $urlname );
 				$this->set_setting( 'use_workflow', 1 );
 				break;
 
 			case 'std':
 			default:
-				$this->set( 'name', T_('My weblog') );
-				$this->set( 'shortname', T_('Blog') );
-				$this->set( 'urlname', 'blog' );
+				$this->set( 'name', empty($name) ? T_('My weblog') : $name );
+				$this->set( 'shortname', empty($shortname) ? T_('Blog') : $shortname );
+				$this->set( 'urlname', empty($urlname) ? 'blog' : $urlname );
 				break;
 		}
 	}
@@ -292,6 +295,16 @@ class Blog extends DataObject
 			$this->set_setting( 'category_prefix', $category_prefix);
 		}
 
+		if( param( 'atom_redirect', 'string', NULL ) !== NULL )
+		{
+			param_check_url( 'atom_redirect', 'commenting' );
+			$this->set_setting( 'atom_redirect', get_param( 'atom_redirect' ) );
+
+			param( 'rss2_redirect', 'string', NULL );
+			param_check_url( 'rss2_redirect', 'commenting' );
+			$this->set_setting( 'rss2_redirect', get_param( 'rss2_redirect' ) );
+		}
+
 		if( param( 'tag_links',   'string', NULL ) !== NULL )
 		{ // Tag page link type:
 			$this->set_setting( 'tag_links', get_param( 'tag_links' ) );
@@ -598,7 +611,6 @@ class Blog extends DataObject
 		}
 
 		return ! param_errors_detected();
-
 	}
 
 
@@ -718,7 +730,7 @@ class Blog extends DataObject
 	}
 
 
-  /**
+	/**
 	 * Generate the baseurl of the blog (URL of the folder where the blog lives)
 	 *
 	 * @todo test
@@ -758,7 +770,7 @@ class Blog extends DataObject
 	}
 
 
-  /**
+	/**
 	 * Load presets
 	 *
 	 * @param string
@@ -773,7 +785,7 @@ class Blog extends DataObject
 				$this->set_setting( 'chapter_links', 'chapters' );
 				$this->set_setting( 'chapter_posts_per_page', NULL );
 				$this->set_setting( 'tag_posts_per_page', NULL );
-				$this->set_setting( 'tag_links', 'semicol' );
+				$this->set_setting( 'tag_links', 'colon' );
 				$this->set_setting( 'single_links', 'ymd' );
 
 				$this->set_setting( 'canonical_item_urls', 1 );
@@ -808,7 +820,7 @@ class Blog extends DataObject
 				$this->set_setting( 'chapter_links', 'subchap' );
 				$this->set_setting( 'chapter_posts_per_page', 10 );
 				$this->set_setting( 'tag_posts_per_page', 10 );
-				$this->set_setting( 'tag_links', 'semicol' );
+				$this->set_setting( 'tag_links', 'colon' );
 				$this->set_setting( 'single_links', 'short' );
 
 				$this->set_setting( 'canonical_item_urls', 1 );
@@ -843,7 +855,7 @@ class Blog extends DataObject
 				$this->set_setting( 'chapter_links', 'chapters' );
 				$this->set_setting( 'chapter_posts_per_page', 20 );
 				$this->set_setting( 'tag_posts_per_page', 20 );
-				$this->set_setting( 'tag_links', 'semicol' );
+				$this->set_setting( 'tag_links', 'colon' );
 				$this->set_setting( 'single_links', 'chapters' );
 
 				$this->set_setting( 'canonical_item_urls', 1 );
@@ -878,7 +890,7 @@ class Blog extends DataObject
 				$this->set_setting( 'chapter_links', 'subchap' );
 				$this->set_setting( 'chapter_posts_per_page', 50 );
 				$this->set_setting( 'tag_posts_per_page', 50 );
-				$this->set_setting( 'tag_links', 'semicol' );
+				$this->set_setting( 'tag_links', 'colon' );
 				$this->set_setting( 'single_links', 'short' );
 
 				$this->set_setting( 'canonical_item_urls', 1 );
@@ -913,7 +925,7 @@ class Blog extends DataObject
 				$this->set_setting( 'chapter_links', 'chapters' );
 				$this->set_setting( 'chapter_posts_per_page', 10 );
 				$this->set_setting( 'tag_posts_per_page', 10 );
-				$this->set_setting( 'tag_links', 'semicol' );
+				$this->set_setting( 'tag_links', 'colon' );
 				$this->set_setting( 'single_links', 'chapters' );
 
 				$this->set_setting( 'canonical_item_urls', 1 );
@@ -945,7 +957,7 @@ class Blog extends DataObject
 	}
 
 
-  /**
+	/**
 	 * Generate archive page URL
 	 *
 	 * Note: there ate two similar functions here.
@@ -1013,8 +1025,9 @@ class Blog extends DataObject
 
 
 	/**
-	 *
+	 * Generate link to archive
 	 * @uses Blog::gen_archive_url()
+	 * @return string HTML A tag
 	 */
 	function gen_archive_link( $text, $title, $year, $month = NULL, $day = NULL, $week = NULL, $glue = '&amp;' )
 	{
@@ -1038,10 +1051,10 @@ class Blog extends DataObject
 	}
 
 
-  /**
+	/**
 	 * Get archive page URL
 	 *
-	 * Note: there ate two similar functions here.
+	 * Note: there are two similar functions here.
 	 *
 	 * @uses Blog::gen_archive_url()
 	 *
@@ -1071,7 +1084,7 @@ class Blog extends DataObject
 	}
 
 
-  /**
+	/**
 	 * Generate a tag url on this blog
 	 */
 	function gen_tag_url( $tag, $paged = 1, $glue = '&amp;' )
@@ -1089,16 +1102,28 @@ class Blog extends DataObject
 				}
 				break;
 
-			case 'semicol':
 			default:
+				switch( $link_type )
+				{
+					case 'dash':
+						$trailer = '-';
+						break;
+					case 'semicolon':
+						$trailer = ';';
+						break;
+					case 'colon':
+					default:
+						$trailer = ':';
+						break;
+				}
 				$tag_prefix = $this->get_setting('tag_prefix');
 				if( !empty( $tag_prefix ) )
 				{
-					$r = url_add_tail( $this->gen_blogurl(), '/'.$tag_prefix.'/'.urlencode( $tag ).';' );
+					$r = url_add_tail( $this->gen_blogurl(), '/'.$tag_prefix.'/'.urlencode( $tag ).$trailer );
 				}
 				else
 				{
-					$r = url_add_tail( $this->gen_blogurl(), '/'.urlencode( $tag ).';' );
+					$r = url_add_tail( $this->gen_blogurl(), '/'.urlencode( $tag ).$trailer );
 				}
 		}
 
@@ -1121,7 +1146,7 @@ class Blog extends DataObject
 	 */
 	function get_allowed_item_status( $status = NULL )
 	{
-    /**
+		/**
 		 * @var User
 		 */
 		global $current_User;
@@ -1347,8 +1372,10 @@ class Blog extends DataObject
 	}
 
 
-  /**
-	 * Callback user for footer_text()
+	/**
+	 * Callback function for footer_text()
+	 * @param array
+	 * @return string
 	 */
 	function replace_callback( $matches )
 	{
@@ -1361,7 +1388,7 @@ class Blog extends DataObject
 				return date( 'Y', $localtimenow );
 
 			case 'owner':
-        /**
+				/**
 				 * @var User
 				 */
 				$owner_User = $this->get_owner_User();
@@ -1778,7 +1805,6 @@ class Blog extends DataObject
 	}
 
 
-
 	/**
 	 * Get the name of the blog
 	 *
@@ -1868,7 +1894,7 @@ class Blog extends DataObject
 	}
 
 
-  /**
+	/**
 	 * @param boolean do we want to redirect back to where we came from after message?
 	 */
 	function get_contact_url( $with_redirect = true )
@@ -1885,7 +1911,26 @@ class Blog extends DataObject
 		return $r;
 	}
 
+
+  /**
+	 * Get # of posts for a given tag
+	 */
+	function get_tag_post_count( $tag )
+	{
+		global $DB;
+
+		$sql = 'SELECT COUNT(DISTINCT itag_itm_ID)
+						  FROM T_items__tag INNER JOIN T_items__itemtag ON itag_tag_ID = tag_ID
+					  				INNER JOIN T_postcats ON itag_itm_ID = postcat_post_ID
+					  				INNER JOIN T_categories ON postcat_cat_ID = cat_ID
+						 WHERE cat_blog_ID = '.$this->ID.'
+						 	 AND tag_name = '.$DB->quote( strtolower($tag) );
+
+		return $DB->get_var( $sql );
+
+	}
 }
 
 
+
 ?>
