@@ -22,7 +22,7 @@
  * @author blueyed: Daniel HAHLER.
  * @author fplanque: Francois PLANQUE
  *
- * @version $Id: _comment.class.php,v 1.14 2008/01/21 09:35:27 fplanque Exp $
+ * @version $Id: _comment.class.php,v 1.14.2.1 2009/01/27 00:45:54 blueyed Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -295,7 +295,7 @@ class Comment extends DataObject
 	{
 		if( $this->get_author_User() )
 		{
-			return $this->author_User->preferred_name( 'raw', false );
+			return $this->author_User->get_preferred_name();
 		}
 		else
 		{
