@@ -29,7 +29,7 @@
  * @author blueyed: Daniel HAHLER.
  * @author fplanque: Francois PLANQUE.
  *
- * @version $Id: _file.funcs.php,v 1.6.2.1 2008/04/26 22:28:53 fplanque Exp $
+ * @version $Id: _file.funcs.php,v 1.6.2.2 2008/05/26 19:22:53 fplanque Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -346,7 +346,7 @@ function no_trailing_slash( $path )
 {
 	if( substr( $path, -1 ) == '/' )
 	{
-		return substr( $path, 0, strlen( $path ) );
+		return substr( $path, 0, strlen( $path )-1 );
 	}
 	else
 	{
