@@ -29,7 +29,7 @@
  * @author blueyed: Daniel HAHLER.
  * @author fplanque: Francois PLANQUE.
  *
- * @version $Id: _file_list.inc.php,v 1.3 2008/01/28 20:17:44 fplanque Exp $
+ * @version $Id: _file_list.inc.php,v 1.3.4.1 2008/05/31 00:12:25 fplanque Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -452,9 +452,9 @@ $Form->begin_form();
 			{	// We are uploading in a popup opened by an edit screen
 				?>
 				<input class="ActionButton"
-					title="<?php echo T_('Insert IMG tags for selected files'); ?>"
+					title="<?php echo T_('Insert IMG or link tags for the selected files, directly into the post text'); ?>"
 					name="actionArray[img_tag]"
-					value="<?php echo T_('Make IMG tags') ?>"
+					value="<?php echo T_('Insert IMG/link into post') ?>"
 					type="submit"
 					onclick="insert_tag_for_selected_files(); return false;" />
 				<?php
