@@ -31,7 +31,7 @@
  * @author gorgeb: Bertrand GORGE / EPISTEMA
  * @author mbruneau: Marc BRUNEAU / PROGIDISTRI
  *
- * @version $Id: _item.class.php,v 1.32.2.3 2008/04/26 22:28:53 fplanque Exp $
+ * @version $Id: _item.class.php,v 1.32.2.7 2009/01/29 15:54:51 tblue246 Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -233,6 +233,7 @@ class Item extends ItemLight
 			$this->set( 'status', 'published' );
 			$this->set( 'locale', $default_locale );
 			$this->set( 'priority', 3 );
+			$this->set( 'ptyp_ID', 1 /* Post */ );
 		}
 		else
 		{
@@ -1292,7 +1293,7 @@ class Item extends ItemLight
 		echo $params['before'];
 		echo '<a href="'.$params['form_url'].'" title="'.$params['title'].'"';
 		if( !empty( $params['class'] ) ) echo ' class="'.$params['class'].'"';
-		echo '>'.$params['text'].'</a>';
+		echo ' rel="nofollow">'.$params['text'].'</a>';
 		echo $params['after'];
 
 		return true;
@@ -1326,7 +1327,7 @@ class Item extends ItemLight
 		echo $before;
 		echo '<a href="'.$form_url.'" title="'.$title.'"';
 		if( !empty( $class ) ) echo ' class="'.$class.'"';
-		echo '>'.$text.'</a>';
+		echo ' rel="nofollow">'.$text.'</a>';
 		echo $after;
 
 		return true;
@@ -2345,7 +2346,12 @@ class Item extends ItemLight
 		echo '  dc:identifier="';
 		$this->permanent_url( 'single' );
 		echo '"'."\n";
-		$this->title( '  dc:title="', '"'."\n", false, 'xmlattr' );
+		$this->title( array(
+			'before'    => ' dc:title="',
+			'after'     => '"'."\n",
+			'link_type' => 'none',
+			'format'    => 'xmlattr',
+			) );
 		echo '  trackback:ping="';
 		$this->trackback_url();
 		echo '" />'."\n";
@@ -2396,7 +2402,7 @@ class Item extends ItemLight
 		$params = array_merge( array(
 				'before'        => ' ',
 				'after'         => ' ',
-				'text_template' => '$url$',
+				'text_template' => '$url$',		// If evaluates to empty, nothing will be displayed (except player if podcast)
 				'url_template'  => '$url$',
 				'target'        => '',
 				'format'        => 'htmlbody',
@@ -2421,7 +2427,14 @@ class Item extends ItemLight
 
 		}
 		else
-		{
+		{ // Not displaying podcast player:
+
+			$text = str_replace( '$url$', $this->url, $params['text_template'] );
+			if( empty($text) )
+			{	// Nothing to display
+				return;
+			}
+
 			$r = $params['before'];
 
 			$r .= '<a href="'.str_replace( '$url$', $this->url, $params['url_template'] ).'"';
@@ -2431,7 +2444,7 @@ class Item extends ItemLight
 				$r .= ' target="'.$params['target'].'"';
 			}
 
-			$r .= '>'.str_replace( '$url$', $this->url, $params['text_template'] ).'</a>';
+			$r .= '>'.$text.'</a>';
 
 			$r .= $params['after'];
 
