@@ -32,7 +32,7 @@
  * @author tswicegood: Travis SWICEGOOD.
  * @author vegarg: Vegar BERG GULDAL.
  *
- * @version $Id: _item.funcs.php,v 1.7 2008/01/21 09:35:31 fplanque Exp $
+ * @version $Id: _item.funcs.php,v 1.7.2.3 2009/03/18 15:47:55 tblue246 Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -97,16 +97,24 @@ function init_MainList( $items_nb_limit )
  *
  * Using title as a source if url title is empty
  *
- * @todo Use configurable char as seperator (see tracker)
+ * @todo Use configurable char as separator (see tracker)
  * @todo dh> Allow/Use more than 40 chars
+ * @internal Tblue> What is the purpose of $query_only? Querying the DB
+ * 		but not modifying the URL title makes no sense to me, maybe it
+ * 		would be better to disable the entire query instead. 
  *
  * @param string url title to validate
  * @param string real title to use as a source if $urltitle is empty (encoded in $evo_charset)
  * @param integer ID of post
+ * @param boolean Query the DB, but don't modify the URL title if the title already exists (Useful if you only want to alert the pro user without making changes for him?)
+ * @param string The prefix of the database column names (e. g. "post_" for post_urltitle)
+ * @param string The name of the post ID column
+ * @param string The name of the DB table to use
  * @return string validated url title
  */
 function urltitle_validate( $urltitle, $title, $post_ID = 0, $query_only = false,
-															$dbprefix = 'post_', $dbIDname = 'post_ID', $dbtable = 'T_items__item' )
+									$dbprefix = 'post_', $dbIDname = 'post_ID',
+									$dbtable = 'T_items__item' )
 {
 	global $DB;
 
@@ -131,11 +139,11 @@ function urltitle_validate( $urltitle, $title, $post_ID = 0, $query_only = false
 
 	// Normalize to 40 chars + a number
 	preg_match( '/^(.*?)((-|_)+([0-9]+))?$/', $urltitle, $matches );
-	$urlbase = substr( $matches[1], 0, 40 );
+	$urlbase = rtrim( substr( $matches[1], 0, 40 ), '-' );
 	$urltitle = $urlbase;
 	if( ! empty( $matches[4] ) )
 	{
-		$urltitle = $urlbase.'-'.$matches[4];
+		$urltitle .= '-'.$matches[4];
 	}
 
 
