@@ -32,7 +32,7 @@
  * @todo Make it a class / global object!
  *        - Provide (static) functions to extract .po files / generate _global.php files (single quoted strings!)
  *
- * @version $Id: _locale.funcs.php,v 1.6 2008/02/08 22:24:46 fplanque Exp $
+ * @version $Id: _locale.funcs.php,v 1.6.2.1 2009/04/30 17:09:33 tblue246 Exp $
  */
 if( !defined('EVO_CONFIG_LOADED') ) die( 'Please, do not access this page directly.' );
 
@@ -132,8 +132,20 @@ elseif( $use_l10n == 2 )
 		$messages = $locales[$req_locale]['messages'];
 
 		// replace special characters to msgid-equivalents
-		$search = str_replace( array("\n", "\r", "\t"), array('\n', '', '\t'), $string );
+		$search = preg_replace( array(
+									'|\\\([nrt])|',
+									'|\n|',
+									'|\t|',
+									'|\r|',
+								),
+								array(
+									'\\\\\\\$1',
+									'\\n',
+									'\\t',
+									'',
+								), $string );
 
+		//$Debuglog->add( 'Orig = ['.$string.'], replaced = ['.$search.']', 'locale' );
 		// echo "Translating ", $search, " to $messages<br />";
 
 		if( ! isset($trans[ $messages ] ) )
@@ -175,6 +187,7 @@ elseif( $use_l10n == 2 )
 			$r = convert_charset( $r, $evo_charset, $messages_charset );
 		}
 
+		//$Debuglog->add( 'Result = ['.$r.']', 'locale' );
 		return $r;
 	}
 
