@@ -31,7 +31,7 @@
  * @author fplanque: Francois PLANQUE - {@link http://fplanque.net/}
  * @author blueyed: Daniel HAHLER
  *
- * @version $Id: _plugin.class.php,v 1.6 2008/01/21 09:35:32 fplanque Exp $
+ * @version $Id: _plugin.class.php,v 1.6.2.1 2009/04/30 21:21:16 tblue246 Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -2284,7 +2284,18 @@ class Plugin
 		$messages = $locales[$req_locale]['messages'];
 
 		// replace special characters to msgid-equivalents
-		$search = str_replace( array("\n", "\r", "\t"), array('\n', '', '\t'), $string );
+		$search = preg_replace( array(
+									'|\\\([nrt])|',
+									'|\n|',
+									'|\t|',
+									'|\r|',
+								),
+								array(
+									'\\\\\\\$1',
+									'\\n',
+									'\\t',
+									'',
+								), $string );
 
 		// echo "Translating ", $search, " to $messages<br />";
 
