@@ -21,7 +21,7 @@
  *
  * @author blueyed: Daniel HAHLER
  *
- * @version $Id: _plugins_admin.class.php,v 1.4 2008/01/21 09:35:32 fplanque Exp $
+ * @version $Id: _plugins_admin.class.php,v 1.4.2.1 2009/02/23 20:28:22 blueyed Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -688,10 +688,10 @@ class Plugins_admin extends Plugins
 
 
 		// Delete obsolete events from DB:
-		if( $obsolete_events && $DB->query( "
+		if( $obsolete_events && $DB->query( '
 				DELETE FROM T_pluginevents
-				WHERE pevt_plug_ID = ".$Plugin->ID."
-					AND pevt_event IN ( '".implode( '", "', $obsolete_events )."' )" ) )
+				WHERE pevt_plug_ID = '.$Plugin->ID.'
+				AND pevt_event IN ( "'.implode( '", "', $obsolete_events ).'" )' ) )
 		{
 			$r = true;
 		}
