@@ -29,7 +29,7 @@
  * @author fplanque: Francois PLANQUE.
  * @author blueyed: Daniel HAHLER
  *
- * @version $Id: plugins.ctrl.php,v 1.5 2008/01/21 09:35:32 fplanque Exp $
+ * @version $Id: plugins.ctrl.php,v 1.5.2.1 2009/05/10 17:01:01 tblue246 Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -765,17 +765,20 @@ switch( $action )
 	case 'disp_help_plain': // just the help, without any payload
 		param( 'plugin_class', 'string', true );
 
-		$edit_Plugin = & $admin_Plugins->register( $plugin_class );
+		if( ! ( $edit_Plugin = & $admin_Plugins->get_by_classname( $plugin_class ) ) )
+		{	// Plugin is not installed:
+			$edit_Plugin = & $admin_Plugins->register( $plugin_class );
 
-		if( is_string($edit_Plugin) )
-		{
-			$Messages->add($edit_Plugin, 'error');
-			$edit_Plugin = false;
-			$action = 'list';
-		}
-		else
-		{
-			$admin_Plugins->unregister( $edit_Plugin );
+			if( is_string($edit_Plugin) )
+			{
+				$Messages->add($edit_Plugin, 'error');
+				$edit_Plugin = false;
+				$action = 'list';
+			}
+			else
+			{
+				$admin_Plugins->unregister( $edit_Plugin, true /* force */ );
+			}
 		}
 
 		break;
@@ -1039,4 +1042,4 @@ $AdminUI->disp_payload_end();
 $AdminUI->disp_global_footer();
 
 
-?>
\ No newline at end of file
+?>
