@@ -22,7 +22,7 @@
  * @author blueyed: Daniel HAHLER.
  * @author fplanque: Francois PLANQUE.
  *
- * @version $Id: _skin.funcs.php,v 1.24.2.2 2008/05/11 01:13:34 fplanque Exp $
+ * @version $Id: _skin.funcs.php,v 1.24.2.3 2009/03/23 12:26:09 tblue246 Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -500,8 +500,25 @@ function skin_exists( $name, $filename = 'index.main.php' )
 	return false;
 }
 
+/**
+ * Check if a skin is installed.
+ *
+ * This can either be a regular skin or a skin provided by a plugin.
+ *
+ * @param Skin name (directory name)
+ * @return boolean True if the skin is installed, false otherwise.
+ */
+function skin_installed( $name )
+{
+	$SkinCache = & get_Cache( 'SkinCache' );
 
+	if ( skin_provided_by_plugin( $name ) || $SkinCache->get_by_folder( $name, false ) )
+	{
+		return true;
+	}
 
+	return false;
+}
 
 
 ?>
