@@ -31,7 +31,7 @@
  *
  * @todo separate object inits and permission checks
  *
- * @version $Id: users.ctrl.php,v 1.8.2.1 2008/04/12 19:59:56 fplanque Exp $
+ * @version $Id: users.ctrl.php,v 1.8.2.2 2009/02/01 17:33:38 tblue246 Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -587,9 +587,18 @@ if( !$Messages->count('error') )
 				break;
 			}
 
+			$fullname = $edited_User->dget( 'fullname' );
 			if( param( 'confirm', 'integer', 0 ) )
 			{ // confirmed, Delete from DB:
-				$msg = sprintf( T_('User &laquo;%s&raquo; [%s] deleted.'), $edited_User->dget( 'fullname' ), $edited_User->dget( 'login' ) );
+				if ( ! empty( $fullname ) )
+				{
+					$msg = sprintf( T_('User &laquo;%s&raquo; [%s] deleted.'), $fullname, $edited_User->dget( 'login' ) );
+				}
+				else
+				{
+					$msg = sprintf( T_('User &laquo;%s&raquo; deleted.'), $edited_User->dget( 'login' ) );
+				}
+				
 				$edited_User->dbdelete( $Messages );
 				unset($edited_User);
 				forget_param('user_ID');
@@ -599,7 +608,16 @@ if( !$Messages->count('error') )
 			else
 			{	// not confirmed, Check for restrictions:
 				memorize_param( 'user_ID', 'integer', true );
-				if( ! $edited_User->check_delete( sprintf( T_('Cannot delete User &laquo;%s&raquo; [%s]'), $edited_User->dget( 'fullname' ), $edited_User->dget( 'login' ) ) ) )
+				if ( ! empty( $fullname ) )
+				{
+					$msg = sprintf( T_('Cannot delete User &laquo;%s&raquo; [%s]'), $fullname, $edited_User->dget( 'login' ) );
+				}
+				else
+				{
+					$msg = sprintf( T_('Cannot delete User &laquo;%s&raquo;'), $edited_User->dget( 'login' ) );
+				}
+				
+				if( ! $edited_User->check_delete( $msg ) )
 				{	// There are restrictions:
 					$action = 'view_user';
 				}
@@ -797,9 +815,17 @@ switch( $action )
 
 		case 'delete_user':
 			// We need to ask for confirmation:
-			$edited_User->confirm_delete(
-					sprintf( T_('Delete user &laquo;%s&raquo; [%s]?'), $edited_User->dget( 'fullname' ), $edited_User->dget( 'login' ) ),
-					$action, get_memorized( 'action' ) );
+			$fullname = $edited_User->dget( 'fullname' );
+			if ( ! empty( $fullname ) )
+			{
+				$msg = sprintf( T_('Delete user &laquo;%s&raquo; [%s]?'), $fullname, $edited_User->dget( 'login' ) );
+			}
+			else
+			{
+				$msg = sprintf( T_('Delete user &laquo;%s&raquo;?'), $edited_User->dget( 'login' ) );
+			}
+			
+			$edited_User->confirm_delete( $msg, $action, get_memorized( 'action' ) );
 		case 'new_user':
 		case 'view_user':
 		case 'edit_user':
