@@ -37,7 +37,7 @@
  * @author edgester: Jason EDGECOMBE.
  * @author mfollett: Matt Follett.
  *
- * @version $Id: _functions_create.php,v 1.239.4.2 2008/04/27 17:00:19 fplanque Exp $
+ * @version $Id: _functions_create.php,v 1.239.4.5 2008/09/29 04:33:06 fplanque Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
@@ -222,45 +222,36 @@ function create_default_data()
  * Create a new a blog
  * This funtion has to handle all needed DB dependencies!
  *
- * @todo move this to Blog object
+ * @todo move this to Blog object (only half done here)
  */
 function create_blog(
 	$blog_name,
 	$blog_shortname,
 	$blog_urlname,
-	$blog_staticfilename = '', // obsolete
 	$blog_tagline = '',
 	$blog_longdesc = '',
-	$blog_skin_ID = 1 )
+	$blog_skin_ID = 1,
+	$kind = 'std' ) // standard blog; notorious variation: "photo"
 {
-	global $DB, $default_locale;
+	global $default_locale;
 
-	$query = "INSERT INTO T_blogs( blog_name, blog_shortname, blog_siteurl,
-						blog_urlname,
-						blog_tagline, blog_longdesc, blog_locale,
-						blog_allowcomments, blog_allowtrackbacks,
-						blog_in_bloglist, blog_skin_ID )
-	VALUES ( ";
-	$query .= "'".$DB->escape($blog_name)."', ";
-	$query .= "'".$DB->escape($blog_shortname)."', ";
-	$query .= "'', ";
-	$query .= "'".$DB->escape($blog_urlname)."', ";
-	$query .= "'".$DB->escape($blog_tagline)."', ";
-	$query .= "'".$DB->escape($blog_longdesc)."', ";
-	$query .= "'".$DB->escape($default_locale)."', ";
-	$query .= "'post_by_post', 0, 1, $blog_skin_ID )";
+ 	$Blog = & new Blog( NULL );
 
-	if( ! ($DB->query( $query )) )
-		return false;
+	$Blog->init_by_kind( $kind, $blog_name, $blog_shortname, $blog_urlname );
 
-	$ID = $DB->insert_id;  // blog ID
+	$Blog->set( 'tagline', $blog_tagline );
+	$Blog->set( 'longdesc', $blog_longdesc );
+	$Blog->set( 'locale', $default_locale );
+	$Blog->set( 'skin_ID', $blog_skin_ID );
 
-	$DB->query( 'UPDATE T_blogs
-									SET blog_access_type = "relative",
-											blog_siteurl = "blog'.$ID.'.php"
-								WHERE blog_ID = '.$ID );
+	$Blog->dbinsert();
 
-	return $ID;
+	$Blog->set( 'access_type', 'relative' );
+	$Blog->set( 'siteurl', 'blog'.$Blog->ID.'.php' );
+
+	$Blog->dbupdate();
+
+	return $Blog->ID;
 }
 
 
@@ -279,6 +270,16 @@ function create_demo_contents()
 	global $default_locale, $install_password;
 	global $Plugins;
 
+  /**
+   * @var FileRootCache
+   */
+	global $FileRootCache;
+
+	load_class( 'collections/model/_blog.class.php' );
+	load_class( 'files/model/_file.class.php' );
+	load_class( 'files/model/_filetype.class.php' );
+	load_class( 'items/model/_link.class.php' );
+
 	echo 'Creating demo user... ';
 	$User_Demo = & new User();
 	$User_Demo->set( 'login', 'demouser' );
@@ -310,10 +311,9 @@ function create_demo_contents()
 		$blog_a_long,
 		$blog_shortname,
 		$blog_stub,
-		$blog_stub.'.html',
 		sprintf( T_('Tagline for %s'), $blog_shortname ),
 		sprintf( $default_blog_longdesc, $blog_shortname, '' ),
-		1 ); // Skin ID
+		1, 'std' ); // Skin ID
 
 	$blog_shortname = 'Blog B';
 	$blog_stub = 'b';
@@ -321,10 +321,9 @@ function create_demo_contents()
 		sprintf( T_('%s Title'), $blog_shortname ),
 		$blog_shortname,
 		$blog_stub,
-		$blog_stub.'.html',
 		sprintf( T_('Tagline for %s'), $blog_shortname ),
 		sprintf( $default_blog_longdesc, $blog_shortname, '' ),
-		2 ); // Skin ID
+		2, 'std' ); // Skin ID
 
 	$blog_shortname = 'Linkblog';
 	$blog_stub = 'links';
@@ -335,10 +334,22 @@ function create_demo_contents()
 		'Linkblog',
 		$blog_shortname,
 		$blog_stub,
-		$blog_stub.'.html',
 		T_('Some interesting links...'),
 		sprintf( $default_blog_longdesc, $blog_shortname, $blog_more_longdesc ),
-		3 ); // SKin ID
+		3, 'std' ); // SKin ID
+
+	$blog_shortname = 'Photoblog';
+	$blog_stub = 'photos';
+	$blog_more_longdesc = '<br />
+<br />
+<strong>'.T_("This is a photoblog, optimized for displaying photos.").'</strong>';
+	$blog_photoblog_ID = create_blog(
+		'Photoblog',
+		$blog_shortname,
+		$blog_stub,
+		T_('This blog shows photos...'),
+		sprintf( $default_blog_longdesc, $blog_shortname, $blog_more_longdesc ),
+		4, 'photo' ); // SKin ID
 
 	echo "OK.<br />\n";
 
@@ -366,6 +377,9 @@ function create_demo_contents()
 	$cat_linkblog_b2evo = cat_create( 'b2evolution', 'NULL', $blog_linkblog_ID );
 	$cat_linkblog_contrib = cat_create( 'contributors', 'NULL', $blog_linkblog_ID );
 
+	// Create categories for photoblog
+	$cat_photo_album = cat_create( 'Monument Valley', 'NULL', $blog_photoblog_ID );
+
 	echo "OK.<br />\n";
 
 
@@ -386,6 +400,53 @@ function create_demo_contents()
 <p>It appears in multiple categories.</p>'), $now, $cat_news, array( $cat_ann_a ) );
 
 
+	// PHOTOBLOG:
+  /**
+   * @var FileRootCache
+   */
+	$FileRootCache = & get_Cache( 'FileRootCache' );
+	$FileRoot = & $FileRootCache->get_by_type_and_ID( 'collection', $blog_photoblog_ID, true );
+
+	// Insert a post into photoblog:
+	$now = date('Y-m-d H:i:s',$timestamp++);
+	$edited_Item = & new Item();
+	$edited_Item->insert( 1, T_('Bus Stop Ahead'), 'In the middle of nowhere: a school bus stop where you wouldn\'t really expect it!',
+					 $now, $cat_photo_album, array(), 'published','en-US', '', 'http://fplanque.com/photo/monument-valley' );
+	$edit_File = & new File( $FileRoot->type, $FileRoot->in_type_ID, 'monument-valley/bus-stop-ahead.jpg' );
+	$edit_File->link_to_Item( $edited_Item );
+
+	// Insert a post into photoblog:
+	$now = date('Y-m-d H:i:s',$timestamp++);
+	$edited_Item = & new Item();
+	$edited_Item->insert( 1, T_('John Ford Point'), 'Does this scene look familiar? You\'ve probably seen it in a couple of John Ford westerns!',
+					 $now, $cat_photo_album, array(), 'published','en-US', '', 'http://fplanque.com/photo/monument-valley' );
+	$edit_File = & new File( $FileRoot->type, $FileRoot->in_type_ID, 'monument-valley/john-ford-point.jpg' );
+	$edit_File->link_to_Item( $edited_Item );
+
+	// Insert a post into photoblog:
+	$now = date('Y-m-d H:i:s',$timestamp++);
+	$edited_Item = & new Item();
+	$edited_Item->insert( 1, T_('Monuments'), 'This is one of the most famous views in Monument Valley. I like to frame it with the dirt road in order to give a better idea of the size of those things!',
+					 $now, $cat_photo_album, array(), 'published','en-US', '', 'http://fplanque.com/photo/monument-valley' );
+	$edit_File = & new File( $FileRoot->type, $FileRoot->in_type_ID, 'monument-valley/monuments.jpg' );
+	$edit_File->link_to_Item( $edited_Item );
+
+	// Insert a post into photoblog:
+	$now = date('Y-m-d H:i:s',$timestamp++);
+	$edited_Item = & new Item();
+	$edited_Item->insert( 1, T_('Road to Monument Valley'), 'This gives a pretty good idea of the Monuments you\'re about to drive into...',
+					 $now, $cat_photo_album, array(), 'published','en-US', '', 'http://fplanque.com/photo/monument-valley' );
+	$edit_File = & new File( $FileRoot->type, $FileRoot->in_type_ID, 'monument-valley/monument-valley-road.jpg' );
+	$edit_File->link_to_Item( $edited_Item );
+
+	// Insert a post into photoblog:
+	$now = date('Y-m-d H:i:s',$timestamp++);
+	$edited_Item = & new Item();
+	$edited_Item->insert( 1, T_('Monument Valley'), T_('This is a short photo album demo. Use the arrows to navigate between photos. Click on "Index" to see a thumbnail index.'),
+					 $now, $cat_photo_album, array(), 'published','en-US', '', 'http://fplanque.com/photo/monument-valley' );
+	$edit_File = & new File( $FileRoot->type, $FileRoot->in_type_ID, 'monument-valley/monument-valley.jpg' );
+	$edit_File->link_to_Item( $edited_Item );
+
 
 	// POPULATE THE LINKBLOG:
 
@@ -397,7 +458,7 @@ function create_demo_contents()
 	// Insert a post into linkblog:
 	$now = date('Y-m-d H:i:s',$timestamp++);
 	$edited_Item = & new Item();
-	$edited_Item->insert( 1, 'dAniel', '', $now, $cat_linkblog_contrib, array(), 'published',	'de-DE', '', 'http://daniel.hahler.de/', 'disabled', array() );
+	$edited_Item->insert( 1, 'Daniel', '', $now, $cat_linkblog_contrib, array(), 'published',	'de-DE', '', 'http://daniel.hahler.de/', 'disabled', array() );
 
 	// Insert a post into linkblog:
 	$now = date('Y-m-d H:i:s',$timestamp++);
@@ -465,13 +526,6 @@ If needed, a skin can format info pages differently from regular posts."), $now,
 
 
 
-	// Insert a post:
-	$now = date('Y-m-d H:i:s',$timestamp++);
-	$edited_Item = & new Item();
-	$edited_Item->insert( 1, T_("Clean Permalinks!"), T_("b2evolution uses old-style permalinks and feedback links by default. This is to ensure maximum compatibility with various webserver configurations.
-
-Nethertheless, once you feel comfortable with b2evolution, you should try activating clean permalinks in the Global Settings &gt; Link options in the admin interface."), $now, $cat_b2evo );
-
 	// Insert a post:
 	$now = date('Y-m-d H:i:s',$timestamp++);
 	$edited_Item = & new Item();
@@ -563,11 +617,12 @@ This is the extended text. You only see it when you have clicked the "more" link
 	// Insert a post:
 	$now = date('Y-m-d H:i:s',$timestamp++);
 	$edited_Item = & new Item();
-	$edited_Item->insert( 1, T_("Welcome to b2evolution!"), T_("Three blogs have been created with sample contents:
+	$edited_Item->insert( 1, T_("Welcome to b2evolution!"), T_("Four blogs have been created with sample contents:
 <ul>
 	<li><strong>Blog A</strong>: You are currently looking at it. It contains a few sample posts, using simple features of b2evolution.</li>
 	<li><strong>Blog B</strong>: You can access it from a link at the top of the page. It contains information about more advanced features.</li>
 	<li><strong>Linkblog</strong>: By default, the linkblog is included as a \"Blogroll\" in the sidebar of both Blog A &amp; Blog B.</li>
+	<li><strong>Photoblog</strong>: This blog is an example of how you can use b2evolution to showcase photos, with one photo per page as well as a thumbnail index.</li>
 </ul>
 
 You can add new blogs, delete unwanted blogs and customize existing blogs (title, sidebar, skin, widgets, etc.) from the Blog Settings tab in the admin interface."), $now, $cat_ann_a );
