@@ -10,20 +10,17 @@
  * @package evoskins
  * @subpackage atom
  *
- * @version $Id: index.main.php,v 1.12.2.3 2009/01/13 00:02:45 fplanque Exp $
+ * @version $Id: index.main.php,v 1.12.2.4 2009/01/19 21:50:43 tblue246 Exp $
  */
 if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );
 
 
 // EXTERNAL FEED PROVIDER?
-$atom_redirect = $Blog->get_setting('atom_redirect');
-if (!empty($atom_redirect))
+$atom_redirect = $Blog->get_setting( 'atom_redirect' );
+if ( ! empty( $atom_redirect ) && $redir == 'yes' )
 {
-	if( $redir == 'yes' )
-	{
-		header_redirect( $atom_redirect, 301 );
-		exit(0);
-	}
+	header_redirect( $atom_redirect, 301 );
+	exit( 0 );
 }
 
 
@@ -40,7 +37,7 @@ if( $feed_content == 'none' )
 	exit();
 }
 
-if( $debug)
+if( $debug )
 {
 	skin_content_header( 'application/xml' );	// Sets charset!
 }
